@@ -23,11 +23,14 @@ REGEXES = set([
     ("word", re.compile(r"(\w|\.)+", re.U)),
     ("mac", re.compile(r'^(ma?c)(\w{2,})', re.I | re.U)),
     ("initial", re.compile(r'^(\w\.|[A-Z])?$', re.U)),
-    ("nickname", re.compile(r'\s*?[\("](.+?)[\)"]', re.U)),
+    ("quoted_word", re.compile(r'\'([^\s]*?)\'', re.U)),
+    ("double_quotes", re.compile(r'\"(.*?)\"', re.U)),
+    ("parenthesis", re.compile(r'\((.*?)\)', re.U)),
     ("roman_numeral", re.compile(r'^(X|IX|IV|V?I{0,3})$', re.I | re.U)),
     ("no_vowels",re.compile(r'^[^aeyiuo]+$', re.I | re.U)),
     ("period_not_at_end",re.compile(r'.*\..+$', re.I | re.U)),
     ("emoji",re_emoji),
+    ("phd", re.compile(r'\s(ph\.?\s+d\.?)', re.I | re.U)),
 ])
 """
 All regular expressions used by the parser are precompiled and stored in the config.
