@@ -194,7 +194,6 @@ TITLES = FIRST_NAME_TITLES | set([
     'comtesse',
     'conductor',
     'consultant',
-    'contessa',
     'controller',
     'corporal',
     'corporate',
@@ -245,6 +244,7 @@ TITLES = FIRST_NAME_TITLES | set([
     'doyen',
     'dpty',
     'dr',
+    'dra',
     'dramatist',
     'druid',
     'drummer',
@@ -566,6 +566,7 @@ TITLES = FIRST_NAME_TITLES | set([
     'special',
     'sr',
     'sra',
+    'srta',
     'ssg',
     'ssgt',
     'staff',
