@@ -46,14 +46,13 @@ class HumanNameTestBase(unittest.TestCase):
             self.assertEqual(actual, expected, "'%s' != '%s' for '%s'\n%r" % (
                 actual,
                 expected,
-                hn.full_name,
+                hn.original,
                 hn
             ))
         except UnicodeDecodeError:
             self.assertEquals(actual, expected)
 
 
-
 class HumanNamePythonTests(HumanNameTestBase):
 
     def test_utf8(self):
@@ -77,12 +76,12 @@ class HumanNamePythonTests(HumanNameTestBase):
         hn = HumanName("John Doe")
         self.m(len(hn), 2, hn)
 
-    @unittest.skipUnless(dill,"requires python-dill module to test pickling")
+    @unittest.skipUnless(dill, "requires python-dill module to test pickling")
     def test_config_pickle(self):
-        C = Constants()
-        self.assertTrue(dill.pickles(C))
+        constants = Constants()
+        self.assertTrue(dill.pickles(constants))
 
-    @unittest.skipUnless(dill,"requires python-dill module to test pickling")
+    @unittest.skipUnless(dill, "requires python-dill module to test pickling")
     def test_name_instance_pickle(self):
         hn = HumanName("Title First Middle Middle Last, Jr.")
         self.assertTrue(dill.pickles(hn))
@@ -91,7 +90,7 @@ class HumanNamePythonTests(HumanNameTestBase):
         hn1 = HumanName("Doe-Ray, Dr. John P., CLU, CFP, LUTC")
         hn2 = HumanName("Dr. John P. Doe-Ray, CLU, CFP, LUTC")
         self.assertTrue(hn1 == hn2)
-        self.assertTrue(not hn1 is hn2)
+        self.assertTrue(hn1 is not hn2)
         self.assertTrue(hn1 == "Dr. John P. Doe-Ray CLU, CFP, LUTC")
         hn1 = HumanName("Doe, Dr. John P., CLU, CFP, LUTC")
         hn2 = HumanName("Dr. John P. Doe-Ray, CLU, CFP, LUTC")
@@ -127,17 +126,17 @@ class HumanNamePythonTests(HumanNameTestBase):
         with self.assertRaises(TypeError):
             hn.suffix = [['test']]
         with self.assertRaises(TypeError):
-            hn.suffix = {"test":"test"}
+            hn.suffix = {"test": "test"}
 
     def test_assign_list_to_attribute(self):
         hn = HumanName("John A. Kenneth Doe, Jr.")
-        hn.title = ["test1","test2"]
+        hn.title = ["test1", "test2"]
         self.m(hn.title, "test1 test2", hn)
-        hn.first = ["test3","test4"]
+        hn.first = ["test3", "test4"]
         self.m(hn.first, "test3 test4", hn)
-        hn.middle = ["test5","test6","test7"]
+        hn.middle = ["test5", "test6", "test7"]
         self.m(hn.middle, "test5 test6 test7", hn)
-        hn.last = ["test8","test9","test10"]
+        hn.last = ["test8", "test9", "test10"]
         self.m(hn.last, "test8 test9 test10", hn)
         hn.suffix = ['test']
         self.m(hn.suffix, "test", hn)
@@ -146,13 +145,13 @@ class HumanNamePythonTests(HumanNameTestBase):
         hn1 = HumanName("Doe-Ray, Dr. John P., CLU, CFP, LUTC")
         hn2 = HumanName("dr. john p. doe-Ray, CLU, CFP, LUTC")
         self.assertTrue(hn1 == hn2)
-        self.assertTrue(not hn1 is hn2)
+        self.assertTrue(hn1 is not hn2)
         self.assertTrue(hn1 == "Dr. John P. Doe-ray clu, CFP, LUTC")
 
     def test_slice(self):
         hn = HumanName("Doe-Ray, Dr. John P., CLU, CFP, LUTC")
         self.m(list(hn), ['Dr.', 'John', 'P.', 'Doe-Ray', 'CLU, CFP, LUTC'], hn)
-        self.m(hn[1:], ['John', 'P.', 'Doe-Ray', 'CLU, CFP, LUTC',hn.C.empty_attribute_default], hn)
+        self.m(hn[1:], ['John', 'P.', 'Doe-Ray', 'CLU, CFP, LUTC', hn.C.empty_attribute_default], hn)
         self.m(hn[1:-2], ['John', 'P.', 'Doe-Ray'], hn)
 
     def test_getitem(self):
@@ -167,12 +166,12 @@ class HumanNamePythonTests(HumanNameTestBase):
         hn = HumanName("Dr. John A. Kenneth Doe, Jr.")
         hn['title'] = 'test'
         self.m(hn['title'], "test", hn)
-        hn['last'] = ['test','test2']
+        hn['last'] = ['test', 'test2']
         self.m(hn['last'], "test test2", hn)
         with self.assertRaises(TypeError):
             hn["suffix"] = [['test']]
         with self.assertRaises(TypeError):
-            hn["suffix"] = {"test":"test"}
+            hn["suffix"] = {"test": "test"}
 
     def test_conjunction_names(self):
         hn = HumanName("johnny y")
@@ -189,6 +188,14 @@ class HumanNamePythonTests(HumanNameTestBase):
         self.m(hn.first, "", hn)
         self.m(hn.last, "", hn)
 
+    def test_surnames_list_attribute(self):
+        hn = HumanName("John Edgar Casey Williams III")
+        self.m(hn.surnames_list, ["Edgar", "Casey", "Williams"], hn)
+
+    def test_surnames_attribute(self):
+        hn = HumanName("John Edgar Casey Williams III")
+        self.m(hn.surnames, "Edgar Casey Williams", hn)
+
 
 class FirstNameHandlingTests(HumanNameTestBase):
     def test_first_name(self):
@@ -1253,26 +1260,32 @@ class ConstantsCustomization(HumanNameTestBase):
 
     def test_add_title(self):
         hn = HumanName("Te Awanui-a-Rangi Black", constants=None)
+        start_len = len(hn.C.titles)
+        self.assert_(start_len > 0)
         hn.C.titles.add('te')
+        self.assertEqual(start_len + 1, len(hn.C.titles))
         hn.parse_full_name()
-        self.m(hn.title,"Te", hn)
-        self.m(hn.first,"Awanui-a-Rangi", hn)
-        self.m(hn.last,"Black", hn)
+        self.m(hn.title, "Te", hn)
+        self.m(hn.first, "Awanui-a-Rangi", hn)
+        self.m(hn.last, "Black", hn)
     
     def test_remove_title(self):
         hn = HumanName("Hon Solo", constants=None)
+        start_len = len(hn.C.titles)
+        self.assert_(start_len > 0)
         hn.C.titles.remove('hon')
+        self.assertEqual(start_len - 1, len(hn.C.titles))
         hn.parse_full_name()
-        self.m(hn.first,"Hon", hn)
-        self.m(hn.last,"Solo", hn)
+        self.m(hn.first, "Hon", hn)
+        self.m(hn.last, "Solo", hn)
     
     def test_add_multiple_arguments(self):
         hn = HumanName("Assoc Dean of Chemistry Robert Johns", constants=None)
         hn.C.titles.add('dean', 'Chemistry')
         hn.parse_full_name()
-        self.m(hn.title,"Assoc Dean of Chemistry", hn)
-        self.m(hn.first,"Robert", hn)
-        self.m(hn.last,"Johns", hn)
+        self.m(hn.title, "Assoc Dean of Chemistry", hn)
+        self.m(hn.first, "Robert", hn)
+        self.m(hn.last, "Johns", hn)
 
     def test_instances_can_have_own_constants(self):
         hn = HumanName("", None)
@@ -1282,8 +1295,7 @@ class ConstantsCustomization(HumanNameTestBase):
         self.assertEqual(hn.has_own_config, True)
         self.assertEqual('hon' in hn2.C.titles, True)
         self.assertEqual(hn2.has_own_config, False)
-    
-    
+
     def test_can_change_global_constants(self):
         hn = HumanName("")
         hn2 = HumanName("")
@@ -1299,18 +1311,18 @@ class ConstantsCustomization(HumanNameTestBase):
         hn = HumanName("Ms Hon Solo", constants=None)
         hn.C.titles.remove('hon', 'ms')
         hn.parse_full_name()
-        self.m(hn.first,"Ms", hn)
-        self.m(hn.middle,"Hon", hn)
-        self.m(hn.last,"Solo", hn)
+        self.m(hn.first, "Ms", hn)
+        self.m(hn.middle, "Hon", hn)
+        self.m(hn.last, "Solo", hn)
 
     def test_chain_multiple_arguments(self):
         hn = HumanName("Dean Ms Hon Solo", constants=None)
         hn.C.titles.remove('hon', 'ms').add('dean')
         hn.parse_full_name()
-        self.m(hn.title,"Dean", hn)
-        self.m(hn.first,"Ms", hn)
-        self.m(hn.middle,"Hon", hn)
-        self.m(hn.last,"Solo", hn)
+        self.m(hn.title, "Dean", hn)
+        self.m(hn.first, "Ms", hn)
+        self.m(hn.middle, "Hon", hn)
+        self.m(hn.last, "Solo", hn)
 
     def test_empty_attribute_default(self):
         from nameparser.config import CONSTANTS
@@ -1346,7 +1358,7 @@ class ConstantsCustomization(HumanNameTestBase):
         self.assertIn('béck', c.titles)
 
 
-class HumanNameNicknameTestCase(HumanNameTestBase):
+class NicknameTestCase(HumanNameTestBase):
     # https://code.google.com/p/python-nameparser/issues/detail?id=33
     def test_nickname_in_parenthesis(self):
         hn = HumanName("Benjamin (Ben) Franklin")
@@ -1355,6 +1367,20 @@ class HumanNameNicknameTestCase(HumanNameTestBase):
         self.m(hn.last, "Franklin", hn)
         self.m(hn.nickname, "Ben", hn)
     
+    def test_two_word_nickname_in_parenthesis(self):
+        hn = HumanName("Benjamin (Big Ben) Franklin")
+        self.m(hn.first, "Benjamin", hn)
+        self.m(hn.middle, "", hn)
+        self.m(hn.last, "Franklin", hn)
+        self.m(hn.nickname, "Big Ben", hn)
+
+    def test_two_words_in_quotes(self):
+        hn = HumanName('Benjamin "Big Ben" Franklin')
+        self.m(hn.first, "Benjamin", hn)
+        self.m(hn.middle, "", hn)
+        self.m(hn.last, "Franklin", hn)
+        self.m(hn.nickname, "Big Ben", hn)
+
     def test_nickname_in_parenthesis_with_comma(self):
         hn = HumanName("Franklin, Benjamin (Ben)")
         self.m(hn.first, "Benjamin", hn)
@@ -1370,9 +1396,6 @@ class HumanNameNicknameTestCase(HumanNameTestBase):
         self.m(hn.suffix, "Jr.", hn)
         self.m(hn.nickname, "Ben", hn)
     
-    # it would be hard to support this without breaking some of the
-    # other examples with single quotes in the names.
-    @unittest.expectedFailure
     def test_nickname_in_single_quotes(self):
         hn = HumanName("Benjamin 'Ben' Franklin")
         self.m(hn.first, "Benjamin", hn)
@@ -1388,9 +1411,9 @@ class HumanNameNicknameTestCase(HumanNameTestBase):
         self.m(hn.nickname, "Ben", hn)
     
     def test_single_quotes_on_first_name_not_treated_as_nickname(self):
-        hn = HumanName("Brian O'connor")
+        hn = HumanName("Brian Andrew O'connor")
         self.m(hn.first, "Brian", hn)
-        self.m(hn.middle, "", hn)
+        self.m(hn.middle, "Andrew", hn)
         self.m(hn.last, "O'connor", hn)
         self.m(hn.nickname, "", hn)
     
@@ -1408,20 +1431,79 @@ class HumanNameNicknameTestCase(HumanNameTestBase):
         self.m(hn.last, "Aube'", hn)
         self.m(hn.nickname, "", hn)
     
-    #http://code.google.com/p/python-nameparser/issues/detail?id=17
-    def test_parenthesis_are_removed(self):
-        hn = HumanName("John Jones (Google Docs)")
+    # http://code.google.com/p/python-nameparser/issues/detail?id=17
+    def test_parenthesis_are_removed_from_name(self):
+        hn = HumanName("John Jones (Unknown)")
         self.m(hn.first, "John", hn)
         self.m(hn.last, "Jones", hn)
         # not testing the nicknames because we don't actually care
-        # about Google Docs.
-        
-    def test_parenthesis_are_removed2(self):
+        # about Google Docs here
+
+    def test_duplicate_parenthesis_are_removed_from_name(self):
         hn = HumanName("John Jones (Google Docs), Jr. (Unknown)")
         self.m(hn.first, "John", hn)
         self.m(hn.last, "Jones", hn)
         self.m(hn.suffix, "Jr.", hn)
 
+    def test_nickname_and_last_name(self):
+        hn = HumanName('"Rick" Edmonds')
+        self.m(hn.first, "", hn)
+        self.m(hn.last, "Edmonds", hn)
+        self.m(hn.nickname, "Rick", hn)
+
+    @unittest.expectedFailure
+    def test_nickname_and_last_name_with_title(self):
+        hn = HumanName('Senator "Rick" Edmonds')
+        self.m(hn.title, "Senator", hn)
+        self.m(hn.first, "", hn)
+        self.m(hn.last, "Edmonds", hn)
+        self.m(hn.nickname, "Rick", hn)
+
+
+
+# class MaidenNameTestCase(HumanNameTestBase):
+#
+#     def test_parenthesis_and_quotes_together(self):
+#         hn = HumanName("Jennifer 'Jen' Jones (Duff)")
+#         self.m(hn.first, "Jennifer", hn)
+#         self.m(hn.last, "Jones", hn)
+#         self.m(hn.nickname, "Jen", hn)
+#         self.m(hn.maiden, "Duff", hn)
+#
+#     def test_maiden_name_with_nee(self):
+#         # https://en.wiktionary.org/wiki/née
+#         hn = HumanName("Mary Toogood nee Johnson")
+#         self.m(hn.first, "Mary", hn)
+#         self.m(hn.last, "Toogood", hn)
+#         self.m(hn.maiden, "Johnson", hn)
+#
+#     def test_maiden_name_with_accented_nee(self):
+#         # https://en.wiktionary.org/wiki/née
+#         hn = HumanName("Mary Toogood née Johnson")
+#         self.m(hn.first, "Mary", hn)
+#         self.m(hn.last, "Toogood", hn)
+#         self.m(hn.maiden, "Johnson", hn)
+#
+#     def test_maiden_name_with_nee_and_comma(self):
+#         # https://en.wiktionary.org/wiki/née
+#         hn = HumanName("Mary Toogood, née Johnson")
+#         self.m(hn.first, "Mary", hn)
+#         self.m(hn.last, "Toogood", hn)
+#         self.m(hn.maiden, "Johnson", hn)
+#
+#     def test_maiden_name_with_nee_with_parenthesis(self):
+#         hn = HumanName("Mary Toogood (nee Johnson)")
+#         self.m(hn.first, "Mary", hn)
+#         self.m(hn.last, "Toogood", hn)
+#         self.m(hn.maiden, "Johnson", hn)
+#
+#     def test_maiden_name_with_parenthesis(self):
+#         hn = HumanName("Mary Toogood (Johnson)")
+#         self.m(hn.first, "Mary", hn)
+#         self.m(hn.last, "Toogood", hn)
+#         self.m(hn.maiden, "Johnson", hn)
+#
+
 class PrefixesTestCase(HumanNameTestBase):
 
     def test_prefix(self):
@@ -1445,6 +1527,12 @@ class PrefixesTestCase(HumanNameTestBase):
         self.m(hn.last, "von bergen wessels", hn)
         self.m(hn.suffix, "III", hn)
 
+    def test_prefix_before_two_part_last_name_with_acronym_suffix(self):
+        hn = HumanName("pennie von bergen wessels M.D.")
+        self.m(hn.first, "pennie", hn)
+        self.m(hn.last, "von bergen wessels", hn)
+        self.m(hn.suffix, "M.D.", hn)
+
     def test_two_part_last_name_with_suffix_comma(self):
         hn = HumanName("pennie von bergen wessels, III")
         self.m(hn.first, "pennie", hn)
@@ -1457,6 +1545,68 @@ class PrefixesTestCase(HumanNameTestBase):
         self.m(hn.last, "von bergen wessels", hn)
         self.m(hn.suffix, "III", hn)
 
+    def test_last_name_two_part_last_name_with_two_suffixes(self):
+        hn = HumanName("von bergen wessels MD, pennie III")
+        self.m(hn.first, "pennie", hn)
+        self.m(hn.last, "von bergen wessels", hn)
+        self.m(hn.suffix, "MD, III", hn)
+
+    def test_comma_two_part_last_name_with_acronym_suffix(self):
+        hn = HumanName("von bergen wessels, pennie MD")
+        self.m(hn.first, "pennie", hn)
+        self.m(hn.last, "von bergen wessels", hn)
+        self.m(hn.suffix, "MD", hn)
+
+    def test_comma_two_part_last_name_with_suffix_in_first_part(self):
+        # I'm kinda surprised this works, not really sure if this is a
+        # realistic place for a suffix to be.
+        hn = HumanName("von bergen wessels MD, pennie")
+        self.m(hn.first, "pennie", hn)
+        self.m(hn.last, "von bergen wessels", hn)
+        self.m(hn.suffix, "MD", hn)
+
+    def test_title_two_part_last_name_with_suffix_in_first_part(self):
+        hn = HumanName("pennie von bergen wessels MD, III")
+        self.m(hn.first, "pennie", hn)
+        self.m(hn.last, "von bergen wessels", hn)
+        self.m(hn.suffix, "MD, III", hn)
+
+    def test_portuguese_dos(self):
+        hn = HumanName("Rafael Sousa dos Anjos")
+        self.m(hn.first, "Rafael", hn)
+        self.m(hn.middle, "Sousa", hn)
+        self.m(hn.last, "dos Anjos", hn)
+
+    def test_portuguese_prefixes(self):
+        hn = HumanName("Joao da Silva do Amaral de Souza")
+        self.m(hn.first, "Joao", hn)
+        self.m(hn.middle, "da Silva do Amaral", hn)
+        self.m(hn.last, "de Souza", hn)
+
+    def test_three_conjunctions(self):
+        hn = HumanName("Dr. Juan Q. Xavier de la dos Vega III")
+        self.m(hn.first, "Juan", hn)
+        self.m(hn.last, "de la dos Vega", hn)
+        self.m(hn.title, "Dr.", hn)
+        self.m(hn.middle, "Q. Xavier", hn)
+        self.m(hn.suffix, "III", hn)
+
+    def test_lastname_three_conjunctions(self):
+        hn = HumanName("de la dos Vega, Dr. Juan Q. Xavier III")
+        self.m(hn.first, "Juan", hn)
+        self.m(hn.last, "de la dos Vega", hn)
+        self.m(hn.title, "Dr.", hn)
+        self.m(hn.middle, "Q. Xavier", hn)
+        self.m(hn.suffix, "III", hn)
+
+    def test_comma_three_conjunctions(self):
+        hn = HumanName("Dr. Juan Q. Xavier de la dos Vega, III")
+        self.m(hn.first, "Juan", hn)
+        self.m(hn.last, "de la dos Vega", hn)
+        self.m(hn.title, "Dr.", hn)
+        self.m(hn.middle, "Q. Xavier", hn)
+        self.m(hn.suffix, "III", hn)
+
 
 class SuffixesTestCase(HumanNameTestBase):
     
@@ -1523,14 +1673,19 @@ class SuffixesTestCase(HumanNameTestBase):
         self.m(hn.last, "Doe", hn)
         self.m(hn.suffix, "jr., MD", hn)
 
-    @unittest.expectedFailure
     def test_phd_with_erroneous_space(self):
         hn = HumanName("John Smith, Ph. D.")
         self.m(hn.first, "John", hn)
         self.m(hn.last, "Smith", hn)
         self.m(hn.suffix, "Ph. D.", hn)
 
-    #http://en.wikipedia.org/wiki/Ma_(surname)
+    def test_phd_conflict(self):
+        hn = HumanName("Adolph D")
+        self.m(hn.first, "Adolph", hn)
+        self.m(hn.last, "D", hn)
+
+
+    # http://en.wikipedia.org/wiki/Ma_(surname)
     def test_potential_suffix_that_is_also_last_name(self):
         hn = HumanName("Jack Ma")
         self.m(hn.first, "Jack", hn)
@@ -1573,23 +1728,23 @@ class SuffixesTestCase(HumanNameTestBase):
         self.m(hn.last, "King", hn)
         self.m(hn.suffix, "Jr", hn)
 
-    def test_suffix_with_periods(self):
+    def test_multiple_letter_suffix_with_periods(self):
         hn = HumanName("John Doe Msc.Ed.")
-        self.m(hn.first,"John", hn)
-        self.m(hn.last,"Doe", hn)
-        self.m(hn.suffix,"Msc.Ed.", hn)
+        self.m(hn.first, "John", hn)
+        self.m(hn.last, "Doe", hn)
+        self.m(hn.suffix, "Msc.Ed.", hn)
 
     def test_suffix_with_periods_with_comma(self):
         hn = HumanName("John Doe, Msc.Ed.")
-        self.m(hn.first,"John", hn)
-        self.m(hn.last,"Doe", hn)
-        self.m(hn.suffix,"Msc.Ed.", hn)
+        self.m(hn.first, "John", hn)
+        self.m(hn.last, "Doe", hn)
+        self.m(hn.suffix, "Msc.Ed.", hn)
 
     def test_suffix_with_periods_with_lastname_comma(self):
         hn = HumanName("Doe, John Msc.Ed.")
-        self.m(hn.first,"John", hn)
-        self.m(hn.last,"Doe", hn)
-        self.m(hn.suffix,"Msc.Ed.", hn)
+        self.m(hn.first, "John", hn)
+        self.m(hn.last, "Doe", hn)
+        self.m(hn.suffix, "Msc.Ed.", hn)
 
 
 class TitleTestCase(HumanNameTestBase):
@@ -1639,7 +1794,7 @@ class TitleTestCase(HumanNameTestBase):
 
     # TODO: fix handling of U.S.
     @unittest.expectedFailure
-    def test_chained_title_first_name_initial(self):
+    def test_chained_title_first_name_title_is_initials(self):
         hn = HumanName("U.S. District Judge Marc Thomas Treadwell")
         self.m(hn.title, "U.S. District Judge", hn)
         self.m(hn.first, "Marc", hn)
@@ -1652,7 +1807,7 @@ class TitleTestCase(HumanNameTestBase):
         self.m(hn.middle, "S.", hn)
         self.m(hn.last, "Grant", hn)
     
-    def test_chained_title_first_name_initial(self):
+    def test_chained_title_first_name_initial_with_no_period(self):
         hn = HumanName("US Magistrate Judge T Michael Putnam")
         self.m(hn.title, "US Magistrate Judge", hn)
         self.m(hn.first, "T", hn)
@@ -1768,8 +1923,8 @@ class TitleTestCase(HumanNameTestBase):
     @unittest.expectedFailure
     def test_ben_as_conjunction(self):
         hn = HumanName("Ahmad ben Husain")
-        self.m(hn.first,"Ahmad", hn)
-        self.m(hn.last,"ben Husain", hn)
+        self.m(hn.first, "Ahmad", hn)
+        self.m(hn.last, "ben Husain", hn)
 
     def test_ben_as_first_name(self):
         hn = HumanName("Ben Johnson")
@@ -1796,15 +1951,16 @@ class TitleTestCase(HumanNameTestBase):
 
     def test_title_with_periods(self):
         hn = HumanName("Lt.Gov. John Doe")
-        self.m(hn.title,"Lt.Gov.", hn)
-        self.m(hn.first,"John", hn)
-        self.m(hn.last,"Doe", hn)
+        self.m(hn.title, "Lt.Gov.", hn)
+        self.m(hn.first, "John", hn)
+        self.m(hn.last, "Doe", hn)
 
     def test_title_with_periods_lastname_comma(self):
         hn = HumanName("Doe, Lt.Gov. John")
-        self.m(hn.title,"Lt.Gov.", hn)
-        self.m(hn.first,"John", hn)
-        self.m(hn.last,"Doe", hn)
+        self.m(hn.title, "Lt.Gov.", hn)
+        self.m(hn.first, "John", hn)
+        self.m(hn.last, "Doe", hn)
+
 
 class HumanNameCapitalizationTestCase(HumanNameTestBase):
     def test_capitalization_exception_for_III(self):
@@ -1874,11 +2030,22 @@ class HumanNameCapitalizationTestCase(HumanNameTestBase):
         hn.capitalize()
         self.m(str(hn), 'Mack Johnson', hn)
 
+    def test_portuguese_prefixes(self):
+        hn = HumanName("joao da silva do amaral de souza")
+        hn.capitalize()
+        self.m(str(hn), 'Joao da Silva do Amaral de Souza', hn)
+
+    def test_capitalize_prefix_clash_on_first_name(self):
+        hn = HumanName("van nguyen")
+        hn.capitalize()
+        self.m(str(hn), 'Van Nguyen', hn)
+
+
 class HumanNameOutputFormatTests(HumanNameTestBase):
     
     def test_formatting_init_argument(self):
-        hn = HumanName("Rev John A. Kenneth Doe III (Kenny)", 
-            string_format = "TEST1")
+        hn = HumanName("Rev John A. Kenneth Doe III (Kenny)",
+                        string_format="TEST1")
         self.assertEqual(u(hn), "TEST1")
 
     def test_formatting_constants_attribute(self):
@@ -1917,51 +2084,51 @@ class HumanNameOutputFormatTests(HumanNameTestBase):
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III 'Kenny'")
         hn.string_format = "{title} {first} {middle} {last} {suffix}"
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III")
-        hn.middle=''
+        hn.middle = ''
         self.assertEqual(u(hn), "Rev John Doe III")
-        hn.suffix=''
+        hn.suffix = ''
         self.assertEqual(u(hn), "Rev John Doe")
-        hn.title=''
+        hn.title = ''
         self.assertEqual(u(hn), "John Doe")
 
     def test_formating_of_nicknames_with_parenthesis(self):
         hn = HumanName("Rev John A. Kenneth Doe III (Kenny)")
         hn.string_format = "{title} {first} {middle} {last} {suffix} ({nickname})"
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III (Kenny)")
-        hn.nickname=''
+        hn.nickname = ''
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III")
 
     def test_formating_of_nicknames_with_single_quotes(self):
         hn = HumanName("Rev John A. Kenneth Doe III (Kenny)")
         hn.string_format = "{title} {first} {middle} {last} {suffix} '{nickname}'"
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III 'Kenny'")
-        hn.nickname=''
+        hn.nickname = ''
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III")
 
     def test_formating_of_nicknames_with_double_quotes(self):
         hn = HumanName("Rev John A. Kenneth Doe III (Kenny)")
         hn.string_format = "{title} {first} {middle} {last} {suffix} \"{nickname}\""
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III \"Kenny\"")
-        hn.nickname=''
+        hn.nickname = ''
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III")
 
     def test_formating_of_nicknames_in_middle(self):
         hn = HumanName("Rev John A. Kenneth Doe III (Kenny)")
         hn.string_format = "{title} {first} ({nickname}) {middle} {last} {suffix}"
         self.assertEqual(u(hn), "Rev John (Kenny) A. Kenneth Doe III")
-        hn.nickname=''
+        hn.nickname = ''
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III")
     
     def test_remove_emojis(self):
         hn = HumanName("Sam Smith 😊")
-        self.m(hn.first,"Sam", hn)
-        self.m(hn.last,"Smith", hn)
+        self.m(hn.first, "Sam", hn)
+        self.m(hn.last, "Smith", hn)
         self.assertEqual(u(hn), "Sam Smith")
 
     def test_keep_non_emojis(self):
         hn = HumanName("∫≜⩕ Smith 😊")
-        self.m(hn.first,"∫≜⩕", hn)
-        self.m(hn.last,"Smith", hn)
+        self.m(hn.first, "∫≜⩕", hn)
+        self.m(hn.last, "Smith", hn)
         self.assertEqual(u(hn), "∫≜⩕ Smith")
 
     def test_keep_emojis(self):
@@ -1969,11 +2136,12 @@ class HumanNameOutputFormatTests(HumanNameTestBase):
         constants = Constants()
         constants.regexes.emoji = False
         hn = HumanName("∫≜⩕ Smith😊", constants)
-        self.m(hn.first,"∫≜⩕", hn)
-        self.m(hn.last,"Smith😊", hn)
+        self.m(hn.first, "∫≜⩕", hn)
+        self.m(hn.last, "Smith😊", hn)
         self.assertEqual(u(hn), "∫≜⩕ Smith😊")
         # test cleanup
 
+
 TEST_NAMES = (
     "John Doe",
     "John Doe, Jr.",
@@ -2147,6 +2315,8 @@ TEST_NAMES = (
     "Designated Judge David A. Ezra",
     "Sr US District Judge Richard G Kopf",
     "U.S. District Judge Marc Thomas Treadwell",
+    "Dra. Andréia da Silva",
+    "Srta. Andréia da Silva",
     
 )
 
@@ -2162,7 +2332,7 @@ class HumanNameVariationTests(HumanNameTestBase):
             hn = HumanName(name)
             if len(hn.suffix_list) > 1:
                 hn = HumanName("{title} {first} {middle} {last} {suffix}".format(**hn.as_dict()).split(',')[0])
-            hn.C.empty_attribute_default = '' # format strings below require empty string
+            hn.C.empty_attribute_default = ''  # format strings below require empty string
             hn_dict = hn.as_dict()
             attrs = [
                 'title',
@@ -2194,11 +2364,11 @@ if __name__ == '__main__':
     if len(sys.argv) > 1:
         log.setLevel(logging.ERROR)
         log.addHandler(logging.StreamHandler())
-        name = sys.argv[1]
-        hn = HumanName(name, encoding=sys.stdout.encoding)
-        print((repr(hn)))
-        hn.capitalize()
-        print((repr(hn)))
+        name_string = sys.argv[1]
+        hn_instance = HumanName(name_string, encoding=sys.stdout.encoding)
+        print((repr(hn_instance)))
+        hn_instance.capitalize()
+        print((repr(hn_instance)))
     else:
         print("-"*80)
         print("Running tests")
